# Generated by Django 3.2.9 on 2022-06-13 09:26

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('privacy_policy_tools', '0003_auto_20220602_0950'),
    ]

    operations = [
        migrations.AddField(
            model_name='privacypolicy',
            name='active',
            field=models.BooleanField(default=False, verbose_name='Active'),
        ),
    ]



# Generated by Django 3.2.16 on 2023-02-02 10:59

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('privacy_policy_tools', '0005_auto_20221216_1110'),
    ]

    operations = [
        migrations.AddField(
            model_name='privacypolicy',
            name='confirm_button_text',
            field=models.CharField(default='Agree', max_length=128, verbose_name='Confirm button text'),
        ),
        migrations.AddField(
            model_name='privacypolicy',
            name='confirm_button_text_de',
            field=models.CharField(default='Agree', max_length=128, null=True, verbose_name='Confirm button text'),
        ),
        migrations.AddField(
            model_name='privacypolicy',
            name='confirm_button_text_en',
            field=models.CharField(default='Agree', max_length=128, null=True, verbose_name='Confirm button text'),
        ),
        migrations.AddField(
            model_name='privacypolicy',
            name='confirm_checkbox',
            field=models.BooleanField(default=False, verbose_name='Confirm checkbox'),
        ),
        migrations.AddField(
            model_name='privacypolicy',
            name='confirm_checkbox_text',
            field=models.CharField(default='I agree to the terms of this privacy policy', max_length=128, verbose_name='Confirm checkbox text'),
        ),
        migrations.AddField(
            model_name='privacypolicy',
            name='confirm_checkbox_text_de',
            field=models.CharField(default='I agree to the terms of this privacy policy', max_length=128, null=True, verbose_name='Confirm checkbox text'),
        ),
        migrations.AddField(
            model_name='privacypolicy',
            name='confirm_checkbox_text_en',
            field=models.CharField(default='I agree to the terms of this privacy policy', max_length=128, null=True, verbose_name='Confirm checkbox text'),
        ),
    ]




# Copyright (c) 2022 Josef Wachtler
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

"""
This module provides some helper functions of the privacy_policy_tools.
"""

from django.conf import settings
from django.contrib.auth.models import Group
from django.http import Http404
from django.utils import timezone

from privacy_policy_tools.models import PrivacyPolicy, \
    PrivacyPolicyConfirmation


def get_active_policies():
    """
    Returns a list of active policies.
    """
    policies = []
    try:
        nogroup = PrivacyPolicy.objects.filter(
            for_group=None, active=True).order_by('-published_at')
        policies.extend(nogroup)
    except PrivacyPolicy.DoesNotExist:
        pass
    groups = Group.objects.all()
    for group in groups:
        try:
            active = group.privacypolicy_set.filter(
                active=True).order_by('-published_at')
            policies.extend(active)
        except PrivacyPolicy.DoesNotExist:
            pass
    return policies


def get_setting(key, default=None):
    """
    Returns a settings value.

    Keyword arguments:
        - key -- name of the settings value
        - default -- default value
    """
    try:
        return settings.PRIVACY_POLICY_TOOLS.get(key, default)
    except AttributeError:
        return None
    except KeyError:
        return None


def save_confirmation(user):
    """
    Saves a confirmation to policies according to the given user.

    Keyword arguments:
        - user -- user object
    """
    policies = get_active_policies()
    if len(policies) <= 0:
        raise Http404
    for policy in policies:
        if get_setting('DEFAULT_POLICY', True):
            no = policy.for_group is None
        else:
            no = policy.for_group is None \
                and len(user.groups.all()) <= 0
        if policy.for_group in user.groups.all() or no:
            confirms = PrivacyPolicyConfirmation.objects.filter(
                privacy_policy=policy, user=user)
            if len(confirms) <= 0:
                confirmation = PrivacyPolicyConfirmation(
                    user=user,
                    confirmed_at=timezone.now(),
                    privacy_policy=policy)
                confirmation.save()




# Copyright (c) 2022 Josef Wachtler
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

"""
This module provides the admin settings of the privacy_policy_tools.
"""

from django.contrib import admin
from modeltranslation.admin import TranslationAdmin

from privacy_policy_tools.models import PrivacyPolicy, \
    PrivacyPolicyConfirmation


class PrivacyPolicyConfirmationInline(admin.TabularInline):
    """
    This admin inline handles the Privacy Policy Confirmations.
    """
    model = PrivacyPolicyConfirmation
    fields = ('user', 'privacy_policy', 'confirmed_at', )
    extra = 0


class PrivacyPolicyAdmin(TranslationAdmin):
    """
    Creating and editing Privacy Policies. The confirmations
    are shown inline.
    """
    list_display = ('title', 'published_at', 'for_group', 'active')
    list_filter = ['published_at', 'active']
    search_fields = ['title', 'text']
    date_hierarchy = 'published_at'

    inlines = [PrivacyPolicyConfirmationInline]


admin.site.register(PrivacyPolicy, PrivacyPolicyAdmin)




# Copyright (c) 2022 Josef Wachtler
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

"""
This module provides the models of the privacy_policy_tools.
"""

from django.db import models
from django.contrib.auth.models import Group, User
from django.utils import timezone
from django.utils.translation import ugettext_lazy as _
from ckeditor.fields import RichTextField


class PrivacyPolicy(models.Model):
    """
    This model saves different versions of privacy policies which have to
    be accepted by the user.

    Fields:
        - title -- title of the policy
        - text -- text of the policy
        - active -- true if the policy is active
        - published_at -- date of publishing
        - for_group -- user group
    """
    title = models.CharField(max_length=128, verbose_name=_('Title'),
                             default=_('Privacy Policy'))
    text = RichTextField(verbose_name=_('Text'))
    confirm_checkbox = models.BooleanField(
        default=False, verbose_name=_('Confirm checkbox'))
    confirm_checkbox_text = models.CharField(
        max_length=128, verbose_name=_('Confirm checkbox text'),
        default=_('I agree to the terms of this privacy policy'))
    confirm_button_text = models.CharField(
        max_length=128, verbose_name=_('Confirm button text'),
        default=_('Agree'))
    active = models.BooleanField(default=False, verbose_name=_('Active'))
    published_at = models.DateTimeField(default=timezone.now,
                                        verbose_name=_('Published at'))
    for_group = models.ForeignKey(Group, on_delete=models.CASCADE,
                                  blank=True, null=True,
                                  verbose_name=_('For group'))

    def __str__(self):
        """
        Unicode representation
        """
        return _('Privacy Policy') + ': ' + str(self.published_at)

    class Meta:
        verbose_name = _('Privacy Policy')
        verbose_name_plural = _('Privacy Policies')


class PrivacyPolicyConfirmation(models.Model):
    """
    This model saves when a user confirmed a Privacy
    Policy.

    Fields:
        - user -- confirming user
        - confirmed_at -- date and time of confirmation
        - privacy_policy -- the confirmed privacy policy
    """
    user = models.ForeignKey(User,
                             on_delete=models.CASCADE,
                             verbose_name=_('User'))
    confirmed_at = models.DateTimeField(default=timezone.now,
                                        verbose_name=_('Confirmed at'))
    privacy_policy = models.ForeignKey(PrivacyPolicy,
                                       on_delete=models.CASCADE,
                                       verbose_name=_('Privacy Policy'))

    def __str__(self):
        """
        Unicode Representation
        """
        return _('Confirmed at') + ': ' + str(self.confirmed_at)

    class Meta:
        verbose_name = _('Privacy Policy Confirmation')
        verbose_name_plural = _('Privacy Policy Confirmations')



# Generated by Django 3.2.9 on 2022-06-02 07:50

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('privacy_policy_tools', '0002_alter_privacypolicy_for_group'),
    ]

    operations = [
        migrations.AddField(
            model_name='privacypolicy',
            name='title',
            field=models.CharField(default='Privacy Policy', max_length=128, verbose_name='Title'),
        ),
        migrations.AddField(
            model_name='privacypolicy',
            name='title_de',
            field=models.CharField(default='Privacy Policy', max_length=128, null=True, verbose_name='Title'),
        ),
        migrations.AddField(
            model_name='privacypolicy',
            name='title_en',
            field=models.CharField(default='Privacy Policy', max_length=128, null=True, verbose_name='Title'),
        ),
    ]




# Copyright (c) 2022 Josef Wachtler
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

"""
This module provides some context processors.
"""

from privacy_policy_tools.utils import get_setting


def privacy_tools(request):
    """
    Adds some values to the templates.

    Values:
        - privacy_enabled -- true if the privacy policy tools are enabled
        - privacy_view -- name of the view to show the policies

    Keyword arguments:
        - request -- the calling HttpRequest
    """
    enabled = get_setting(
        'ENABLED',
        'terms/and/conditions'
    )
    v = {
        'privacy_enabled': enabled,
        'privacy_view': 'privacy_policy_tools.views.show'
    }

    return v




# Copyright (c) 2022 Josef Wachtler
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

"""
This module provides some middleware for the package privacy_policy_tools.
"""
from django.http import HttpResponseRedirect
from django.urls import reverse
from privacy_policy_tools.utils import get_setting, get_active_policies
from privacy_policy_tools.models import PrivacyPolicyConfirmation


class PrivacyPolicyMiddleware(object):
    """
    This middleware class forces the user to confirm the privacy policies.
    """

    def __init__(self, get_response):
        """
        constructor: sets get_response
        """
        self.get_response = get_response

    def __call__(self, request):
        """
        Processes the request and redirect to the privacy policy if
        the user has not confirmed it yet.

        Keyword arguments:
            - request -- calling HttpRequest
        """
        response = self.get_response(request)
        enabled = get_setting('ENABLED')
        if enabled is None:
            return response
        if enabled is True:
            url = get_setting(
                'POLICY_PAGE_URL',
                'terms/and/conditions'
            )
            ignore_urls = get_setting(
                'IGNORE_URLS',
                []
            )
            if request.user.is_authenticated and \
                    url not in request.path_info and \
                    all(ignore not in request.path_info
                        for ignore in ignore_urls):
                policies = get_active_policies()
                if len(policies) <= 0:
                    return response
                for policy in policies:
                    if get_setting('DEFAULT_POLICY', True):
                        no = policy.for_group is None
                    else:
                        no = policy.for_group is None \
                            and len(request.user.groups.all()) <= 0
                    if policy.for_group in request.user.groups.all() or no:
                        confirms = PrivacyPolicyConfirmation.objects.filter(
                            privacy_policy=policy, user=request.user)
                        if len(confirms) <= 0:
                            return HttpResponseRedirect(reverse(
                                'privacy_policy_tools.views.confirm',
                                args=(policy.id, request.path_info,)))
        return response




# Copyright (c) 2022 Josef Wachtler
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

"""
This module designs the urls of the package privacy_policy_tools.
"""

from django.conf.urls import url
from privacy_policy_tools.utils import get_setting
from privacy_policy_tools.views import confirm, show

confirm_url = get_setting('POLICY_CONFIRM_URL')
page_url = get_setting('POLICY_PAGE_URL')

urlpatterns = [
    url(r'^' + page_url + r'$',
     show, name='privacy_policy_tools.views.show'),
    url(r'^' + confirm_url + r'/(?P<policy_id>[0-9]+)$',
     confirm, name='privacy_policy_tools.views.confirm'),
    url(r'^' + confirm_url + r'/(?P<policy_id>[0-9]+)/next(?P<next>.+)$',
     confirm, name='privacy_policy_tools.views.confirm'),
]




# Copyright (c) 2022 Josef Wachtler
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

"""
This module provides the views of the privacy_policy_tools.
"""

from django.http import HttpResponseRedirect
from django.shortcuts import render, get_object_or_404
from django.urls import reverse
from django.utils import timezone

from privacy_policy_tools.models import PrivacyPolicy, \
    PrivacyPolicyConfirmation
from privacy_policy_tools.utils import get_active_policies
from privacy_policy_tools.forms import ConfirmForm


def show(request):
    """
    Displays the Privacy Policies.

    Keyword arguments:
        - request -- the calling HttpRequest

    Template: privacy_policy_tools/show.html
    """
    policies = get_active_policies()
    params = {
        'policies': policies
    }

    return render(
        request, 'privacy_policy_tools/show.html', params)


def confirm(request, policy_id, next='/terms/and/conditions'):
    """
    Displays the Privacy Policy and asks for confirmation.

    Keyword arguments:
        - request -- the calling HttpRequest
        - next -- path to redirect after confirmation

    Template: privacy_policy_tools/confirm.html
    """
    policy = get_object_or_404(PrivacyPolicy, id=policy_id)

    url = reverse('privacy_policy_tools.views.confirm',
                  args=(policy_id,))

    is_confirmed = False
    if request.user.is_authenticated:
        confirmations = PrivacyPolicyConfirmation.objects.filter(
            privacy_policy=policy, user=request.user)
        if len(confirmations) > 0:
            is_confirmed = True
        else:
            url = reverse('privacy_policy_tools.views.confirm',
                          args=(policy_id, next,))

    if request.method == 'POST' and not is_confirmed \
            and request.user.is_authenticated:
        if policy.confirm_checkbox is True:
            form = ConfirmForm(
                request.POST,
                agree_label=policy.confirm_checkbox_text)
            if form.is_valid():
                confirmation = PrivacyPolicyConfirmation(
                    user=request.user,
                    confirmed_at=timezone.now(),
                    privacy_policy=policy)
                confirmation.save()
                return HttpResponseRedirect(next)
        else:
            confirmation = PrivacyPolicyConfirmation(
                user=request.user,
                confirmed_at=timezone.now(),
                privacy_policy=policy)
            confirmation.save()
            return HttpResponseRedirect(next)
    else:
        if policy.confirm_checkbox is True:
            form = ConfirmForm(agree_label=policy.confirm_checkbox_text)

    params = {
        'policy': policy,
        'is_confirmed': is_confirmed,
        'is_authenticated': request.user.is_authenticated,
        'form_url': url
    }
    if policy.confirm_checkbox is True:
        params['form'] = form

    return render(
        request, 'privacy_policy_tools/confirm.html', params)



# Generated by Django 3.2.9 on 2022-03-01 10:43

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('auth', '0012_alter_user_first_name_max_length'),
        ('privacy_policy_tools', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='privacypolicy',
            name='for_group',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='auth.group', verbose_name='For group'),
        ),
    ]



# Generated by Django 3.2.9 on 2022-02-25 10:46

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import django.utils.timezone


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('auth', '0012_alter_user_first_name_max_length'),
    ]

    operations = [
        migrations.CreateModel(
            name='PrivacyPolicy',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('text', models.TextField(verbose_name='Text')),
                ('text_en', models.TextField(null=True, verbose_name='Text')),
                ('text_de', models.TextField(null=True, verbose_name='Text')),
                ('published_at', models.DateTimeField(default=django.utils.timezone.now, verbose_name='Published at')),
                ('for_group', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='auth.group', verbose_name='For group')),
            ],
            options={
                'verbose_name': 'Privacy Policy',
                'verbose_name_plural': 'Privacy Policies',
            },
        ),
        migrations.CreateModel(
            name='PrivacyPolicyConfirmation',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('confirmed_at', models.DateTimeField(default=django.utils.timezone.now, verbose_name='Confirmed at')),
                ('privacy_policy', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='privacy_policy_tools.privacypolicy', verbose_name='Privacy Policy')),
                ('user', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL, verbose_name='User')),
            ],
            options={
                'verbose_name': 'Privacy Policy Confirmation',
                'verbose_name_plural': 'Privacy Policy Confirmations',
            },
        ),
    ]



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="django-privacy-policy-tools",
    version="0.0.4",
    author="Josef Wachtler",
    author_email="josef.wachtler@gmail.com",
    description="This is a highly confirgurable Django app to manage privacy policies and confirmations.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/wachjose88/django-privacy-policy-tools",
    packages=setuptools.find_packages(),
    python_requires='>=3.4',
    install_requires=[
        'django>=3.2.0,<3.3',
        'django-ckeditor'
    ],
    classifiers=[
        "Programming Language :: Python :: 3",
        "Framework :: Django",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)



# Generated by Django 3.2.16 on 2022-12-16 10:10

import ckeditor.fields
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('privacy_policy_tools', '0004_privacypolicy_active'),
    ]

    operations = [
        migrations.AlterField(
            model_name='privacypolicy',
            name='text',
            field=ckeditor.fields.RichTextField(verbose_name='Text'),
        ),
        migrations.AlterField(
            model_name='privacypolicy',
            name='text_de',
            field=ckeditor.fields.RichTextField(null=True, verbose_name='Text'),
        ),
        migrations.AlterField(
            model_name='privacypolicy',
            name='text_en',
            field=ckeditor.fields.RichTextField(null=True, verbose_name='Text'),
        ),
    ]
